@@ -21,18 +21,21 @@ import gconf
 import gconfsource
 import subprocess
 import bonobo
+import xdg.DesktopEntry
 
 try:
     import userprofile
     import util
     from config import *
+    import debuglog
 except:
     from sabayon import userprofile
     from sabayon import util
     from sabayon.config import *
+    from sabayon import debuglog
 
 def dprint (fmt, *args):
-    util.debug_print (util.DEBUG_PANELDELEGATE, fmt % args)
+    debuglog.debug_log (False, debuglog.DEBUG_LOG_DOMAIN_PANEL_DELEGATE, fmt % args)
 
 PANEL_LAUNCHER_DIR = ".gnome2/panel2.d/default/launchers"
 
@@ -193,6 +196,7 @@ class PanelDelegate (userprofile.SourceDelegate):
 		self.object_type = self.client.get_string (PANEL_KEY_BASE + "/objects/" + id + "/object_type")
 	
 		if self.object_type == "drawer-object":
+			# Translators: This is a drawer in gnome-panel (where you can put applets)
 			self.name = _("Drawer")
 		elif self.object_type == "menu-object":
 			self.name = _("Main Menu")
@@ -204,10 +208,8 @@ class PanelDelegate (userprofile.SourceDelegate):
 				desktop_file = launcher_location[7:]
 			else:
 				desktop_file = PANEL_LAUNCHER_DIR + "/" + launcher_location
-
-                        # FIXME: we need to use xdg.DesktopEntry to extract the localized name
-                        # http://bugzilla.gnome.org/show_bug.cgi?id=397742
-                        self.name = _("%s launcher") % launcher_location
+			launcher = xdg.DesktopEntry.DesktopEntry(desktop_file)
+			self.name = _("%s launcher") % launcher.getName()
 		elif self.object_type == "action-applet":
 			action_type = self.client.get_string (PANEL_KEY_BASE + "/objects/" + id + "/action_type")
 			if action_type == "lock":
@@ -215,7 +217,7 @@ class PanelDelegate (userprofile.SourceDelegate):
 			elif action_type == "logout":
 				self.name = _("Logout button")
 			elif action_type == "run":
-				self.name = _("Run Appliction button")
+				self.name = _("Run Application button")
 			elif action_type == "search":
 				self.name = _("Search button")
 			else:
